summaryrefslogtreecommitdiff
path: root/src/signs_cmd.cpp
diff options
context:
space:
mode:
authorrubidium <rubidium@openttd.org>2010-01-11 18:46:09 +0000
committerrubidium <rubidium@openttd.org>2010-01-11 18:46:09 +0000
commit2b97f38cd176d5638053c87199e6ac175d5ee1e4 (patch)
tree85e4776e0646803f4d69f9c700e1712df215be6a /src/signs_cmd.cpp
parent48df0d4e06ee05e56793cc6e638d649126032d4e (diff)
downloadopenttd-2b97f38cd176d5638053c87199e6ac175d5ee1e4.tar.xz
(svn r18781) -Codechange: pass the CommandCost to the callback instead of whether it succeeded or not.
-Fix: AIs did update their last cost incorrectly in network games if the cost of the DC_EXEC phase differed from the ~DC_EXEC phase.
Diffstat (limited to 'src/signs_cmd.cpp')
-rw-r--r--src/signs_cmd.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/signs_cmd.cpp b/src/signs_cmd.cpp
index dff599b65..90ccb89f8 100644
--- a/src/signs_cmd.cpp
+++ b/src/signs_cmd.cpp
@@ -105,17 +105,17 @@ CommandCost CmdRenameSign(TileIndex tile, DoCommandFlag flags, uint32 p1, uint32
/**
* Callback function that is called after a sign is placed
* @param success of the operation
* @param tile unused
* @param p1 unused
* @param p2 unused
*/
-void CcPlaceSign(bool success, TileIndex tile, uint32 p1, uint32 p2)
+void CcPlaceSign(const CommandCost &result, TileIndex tile, uint32 p1, uint32 p2)
{
- if (success) {
- ShowRenameSignWindow(Sign::Get(_new_sign_id));
- ResetObjectToPlace();
- }
+ if (result.Failed()) return;
+
+ ShowRenameSignWindow(Sign::Get(_new_sign_id));
+ ResetObjectToPlace();
}
/**
@@ -105,17 +105,17 @@ CommandCost CmdRenameSign(TileIndex tile, DoCommandFlag flags, uint32 p1, uint32
/**
* Callback function that is called after a sign is placed
- * @param success of the operation
+ * @param result of the operation
* @param tile unused
* @param p1 unused